//---------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "About.h"
#include "LogoMain.h"
#include "LogoStrs.h"
#include "MAPI.hpp"

#include "math.h"
#include <stdlib.h>

//---------------------------------------------------------------------
#pragma resource "*.dfm"
TLogoAppForm *LogoAppForm;
//---------------------------------------------------------------------

//---------------------------------------------------------------------
__fastcall TLogoAppForm::TLogoAppForm(TComponent *Owner)
	: TForm(Owner)
{
    ximage=NULL;
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FormCreate(TObject *Sender)
{
	Application->OnHint = ShowHint;
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileNew(TObject *Sender)
{
	FFileName = LoadStr(sUntitled);
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileOpen(TObject *Sender)
{
    if (OpenDialog->Execute())
    {
	FFileName = OpenDialog->FileName;
        int pos=FFileName.Pos(".");
        if (pos){
            AnsiString ext = FFileName.SubString(1+pos,3);
            ext = ext.LowerCase();
            int type = CxImage::GetTypeIdFromName(ext.c_str());
            if (type != CXIMAGE_FORMAT_UNKNOWN) {
                 if (ximage) delete ximage;
                 ximage = new CxImage();
                 ximage->Load(FFileName.c_str(),type);
                 Invalidate();
            }
        }
     }
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileSave(TObject *Sender)
{
	if (FFileName == LoadStr(sUntitled))
		FileSaveAs(Sender);
	else
	{
	}
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileSaveAs(TObject *Sender)
{
	String str;
	TVarRec vrs[1];

	if (SaveDialog->Execute())
	{
		if (FileExists(SaveDialog->FileName))
		{
			str = FmtLoadStr(sOverwrite, OPENARRAY(TVarRec, (SaveDialog->FileName)));
			if (MessageDlg(str, mtConfirmation, TMsgDlgButtons() << mbYes << mbNo <<
				mbCancel, 0) != IDYES)
				return;
		}
		FFileName = SaveDialog->FileName;

        int pos=FFileName.Pos(".");
        AnsiString ext = FFileName.SubString(1+pos,3);
    	ext = ext.LowerCase();
	if (ext == "") return;

	int type = CxImage::GetTypeIdFromName(ext.c_str());
        if (type == CXIMAGE_FORMAT_UNKNOWN) return;

	bool retval=FALSE;
        if (ximage) retval = ximage->Save(FFileName.c_str(), type);
	    if (retval==FALSE) MessageBox(NULL,ximage->GetLastError(),"Error",MB_OK);
	}
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileSend(TObject *Sender)
{
	TMapiMessage MapiMessage;
	Cardinal MError;

	MapiMessage.ulReserved = 0;
	MapiMessage.lpszSubject = NULL;
	MapiMessage.lpszNoteText = "";
	MapiMessage.lpszMessageType = NULL;
	MapiMessage.lpszDateReceived = NULL;
	MapiMessage.lpszConversationID = NULL;
	MapiMessage.flFlags = 0;
	MapiMessage.lpOriginator = NULL;
	MapiMessage.nRecipCount = 0;
	MapiMessage.lpRecips = NULL;
	MapiMessage.nFileCount = 0;
	MapiMessage.lpFiles = NULL;

	MError = MapiSendMail(0, 0, MapiMessage, MAPI_DIALOG | MAPI_LOGON_UI |
		MAPI_NEW_SESSION, 0);

	if (MError)
		MessageDlg(LoadStr(sSendError), mtError, TMsgDlgButtons() << mbOK, 0);
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::FileExit(TObject *Sender)
{
	Close();
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::About(TObject *Sender)
{
	AboutBox->ShowModal();
}
//---------------------------------------------------------------------
void __fastcall TLogoAppForm::ShowHint(TObject *Sender)
{
	StatusBar->SimpleText = Application->Hint;
}
//---------------------------------------------------------------------

void __fastcall TLogoAppForm::FormPaint(TObject *Sender)
{
//	Canvas->Ellipse(0, 0, radius*2, radius*2);
  if (ximage){
    ximage->Draw(Canvas->Handle,0,32);
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::FormResize(TObject *Sender)
{
     Invalidate();
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::FormDestroy(TObject *Sender)
{
 if (ximage) delete ximage;
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Mirror1Click(TObject *Sender)
{
    if (ximage){
        ximage->Mirror();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Flip1Click(TObject *Sender)
{
    if (ximage){
        ximage->Flip();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Negative1Click(TObject *Sender)
{
    if (ximage){
        ximage->Negative();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::N3Click(TObject *Sender)
{
    if (ximage){
        ximage->Rotate(90.0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::RotateRight1Click(TObject *Sender)
{
    if (ximage){
        ximage->Rotate(-90.0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::GrayScale1Click(TObject *Sender)
{
    if (ximage){
        ximage->GrayScale();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Dither1Click(TObject *Sender)
{
    if (ximage){
        ximage->Dither();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Lighten1Click(TObject *Sender)
{
    if (ximage){
        ximage->Light(20);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Darken1Click(TObject *Sender)
{
    if (ximage){
        ximage->Light(-20);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Contrast1Click(TObject *Sender)
{
    if (ximage){
        ximage->Light((128-ximage->Mean())/4,120);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Erode1Click(TObject *Sender)
{
    if (ximage){
        ximage->Erode();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Dilate1Click(TObject *Sender)
{
    if (ximage){
        ximage->Dilate();
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Blur1Click(TObject *Sender)
{
    if (ximage){
        long kernel[]={1,1,1,1,1,1,1,1,1};
		ximage->Filter(&kernel[0],3,9,0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Soften1Click(TObject *Sender)
{
    if (ximage){
        long kernel[]={1,1,1,1,8,1,1,1,1};
		ximage->Filter(&kernel[0],3,16,0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Sharpen1Click(TObject *Sender)
{
    if (ximage){
        long kernel[]={-1,-1,-1,-1,15,-1,-1,-1,-1};
		ximage->Filter(&kernel[0],3,7,0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Edge1Click(TObject *Sender)
{
    if (ximage){
        long kernel[]={-1,-1,-1,-1,8,-1,-1,-1,-1};
		ximage->Filter(&kernel[0],3,0,0);
        Invalidate();
    }
}
//---------------------------------------------------------------------------

void __fastcall TLogoAppForm::Emboss1Click(TObject *Sender)
{
    if (ximage){
        long kernel[]={-1,0,0,0,0,0,0,0,1};
		ximage->Filter(&kernel[0],3,0,127);
        Invalidate();
    }
}
//---------------------------------------------------------------------------
   /*
void __fastcall TLogoAppForm::TestClick(TObject *Sender)
{
    char fileName[]="C:\\WINDOWS\\Desktop\\colorTif\\multiPageColor2.tif";
    CxImage tempImage(fileName, CXIMAGE_FORMAT_TIF);
    char nameOfTheNewFile[256];

    long nPages = tempImage.GetNumFrames();

    CxImage newImage;
    for (int i = 0; i < nPages; i++) {

        newImage.SetFrame(i);
        if (!newImage.Load(fileName, CXIMAGE_FORMAT_TIF)) return;

        sprintf(nameOfTheNewFile,"%s%d%s", "C:\\WINDOWS\\Desktop\\colorTif\\Page",i+1,".tif");
        newImage.Save(nameOfTheNewFile, CXIMAGE_FORMAT_TIF);
    }


}         */
//---------------------------------------------------------------------------

